@@ -87,7 +87,6 @@ class Kernel:
         self.SqlData = SqlData(self)
         self.RawData = RawData(self)
         self.ObjectData = ObjectData(self)
-        self.MessagingQueue = None
         self.TimeSeriesData = None
 
 
@@ -100,10 +99,6 @@ class Kernel:
         if self.config["visualization_storage"] != "none":
             self.TimeSeriesData = TimeSeriesData(self)
 
-        if self.config["messaging_service"] != "none":
-            from cerebralcortex.core.messaging_manager.messaging_queue import MessagingQueue
-            self.MessagingQueue = MessagingQueue(self, auto_offset_reset)
-
     ###########################################################################
     #                     RAW DATA MANAGER METHODS                            #
     ###########################################################################
@@ -128,6 +123,7 @@ class Kernel:
         """
         return self.RawData.save_stream(datastream=datastream, ingestInfluxDB=ingestInfluxDB, overwrite=overwrite)
 
+    
     def get_stream(self, stream_name: str, version: str = "all", user_id:str=None, data_type=DataSet.COMPLETE) -> DataStream:
         """
         Retrieve a data-stream with it's metadata.
@@ -327,7 +323,6 @@ class Kernel:
         """
         return self.SqlData.create_user(username, user_password, user_role, user_metadata, user_settings, encrypt_password)
 
-
     def delete_user(self, username:str)->bool:
         """
         Delete a user record in SQL table
@@ -683,36 +678,6 @@ class Kernel:
         return self.ObjectData.is_object(bucket_name, object_name)
 
 
-    ###########################################################################
-    #                      Kafka consumer producer                            #
-    ###########################################################################
-
-    def kafka_produce_message(self, msg: dict):
-        """
-        Publish a message on kafka message queue
-
-        Args:
-            msg (dict): message that needs to published on kafka
-        Returns:
-            bool: True if successful. In case of failure, it returns an Exception message.
-        Raises:
-            ValueError: topic and message parameters cannot be empty or None.
-            Exception: Error publishing message. Topic: topic_name - error-message
-
-        """
-        self.MessagingQueue.produce_message(msg)
-
-    def kafka_subscribe_to_topic(self):
-        """
-        Subscribe to kafka topic as a consumer
-
-        Yields:
-             dict: kafka message
-        Raises:
-            ValueError: Topic parameter is missing.
-        """
-        return self.MessagingQueue.subscribe_to_topic()
-
     ################### CACHE RELATED METHODS ##################################
 
     def set_cache_value(self, key: str, value: str) -> bool:
